package com.bigflix.BigFlixMovies;

import android.widget.Toast;

import com.app.pokktsdk.AdConfig;
import com.app.pokktsdk.PokktManager;
import com.app.pokktsdk.delegates.AdCampaignDelegate;

public class AdDelegate implements AdCampaignDelegate {

    private VideoActivity videoActivity;

    public AdDelegate(VideoActivity videoActivity) {
        this.videoActivity = videoActivity;
    }

    @Override
    public void onPokktInitialised(final boolean isReady) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Pokkt SDK Ready " + isReady, Toast.LENGTH_LONG).show();
                    VideoActivity.isPokktSDKReady = isReady;
                    videoActivity.showButtons(0, false);
                    videoActivity.resetButtonsText();
                }
            });
        }
    }

    @Override
    public void onAdCachingCompleted(final AdConfig config, final float result) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Ad Caching Completed ! Ad vc is: " + result, Toast.LENGTH_LONG).show();
                    videoActivity.showButtons(result, true);
                }
            });
        }
    }

    @Override
    public void onAdCachingFailed(final AdConfig config, final String message) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Ad Download Error " + message, Toast.LENGTH_LONG).show();
                    videoActivity.showButtons(PokktManager.getRewardedAdVc(config), false);
                    videoActivity.resetButtonsText();
                }
            });
        }
    }

    @Override
    public void onAdClosed(final AdConfig config, final boolean backPressed) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    if (backPressed) {
                        Toast.makeText(videoActivity, "Ad Closed with Back Button", Toast.LENGTH_LONG).show();
                    } else {
                        Toast.makeText(videoActivity, "Ad Closed", Toast.LENGTH_LONG).show();
                    }
                    videoActivity.showButtons(PokktManager.getRewardedAdVc(config), false);
                    videoActivity.resetButtonsText();
                }
            });
        }
    }

    @Override
    public void onAdCompleted(AdConfig config) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Ad Completed", Toast.LENGTH_LONG).show();
                }
            });
        }
    }

    @Override
    public void onAdDisplayed(AdConfig config) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Ad Displayed", Toast.LENGTH_LONG).show();
                }
            });
        }
    }

    @Override
    public void onAdGratified(final AdConfig config, final float coins) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Points Earned " + coins, Toast.LENGTH_LONG).show();
                    Storage.storeVideoPoints(videoActivity, coins);
                    videoActivity.updateUI(Storage.getVideoPoints(videoActivity));
                }
            });
        }
    }

    @Override
    public void onAdSkipped(AdConfig config) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    Toast.makeText(videoActivity, "Ad Skipped", Toast.LENGTH_LONG).show();
                }
            });
        }
    }

    @Override
    public void onAdAvailabilityStatus(final AdConfig adConfig, final boolean isAvailable) {
        if (videoActivity != null) {
            videoActivity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    if (isAvailable) {
                        Toast.makeText(videoActivity, "Ad Available", Toast.LENGTH_LONG).show();
                    } else {
                        Toast.makeText(videoActivity, "Ad is not Available", Toast.LENGTH_LONG).show();
                    }
                    videoActivity.showButtons(PokktManager.getRewardedAdVc(adConfig), isAvailable);
                    videoActivity.showAd(isAvailable, adConfig);
                }
            });
        }
    }
}
