package com.bigflix.BigFlixMovies;

import android.content.Intent;
import android.content.pm.PackageManager.NameNotFoundException;
import android.content.res.Configuration;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.text.TextUtils;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.app.pokktsdk.PokktManager;
import com.app.pokktsdk.util.AndroidDeviceInfo;
import com.pokkt.videodemo.R;

public class Pokkt extends AppCompatActivity {


	private EditText editTextScreenName;
	private EditText appIdEditText;
	private EditText securityKeyEditText;
	private TextView appIdText;
	private TextView securityKeyText;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		super.onCreate(savedInstanceState);
		setContentView(R.layout.apppage);

		Toolbar actionToolBar = (Toolbar) findViewById(R.id.actionToolbar);
		actionToolBar.setTitle("");
		actionToolBar.showOverflowMenu();
		setSupportActionBar(actionToolBar);

		editTextScreenName = (EditText)findViewById(R.id.editScreenName);

		appIdEditText = (EditText)findViewById(R.id.appIdEdit);
		appIdEditText.setText(Storage.getAppId(this));
		securityKeyEditText = (EditText)findViewById(R.id.securityKeyEdit);
		appIdText = (TextView)findViewById(R.id.appIdText);
		securityKeyText = (TextView)findViewById(R.id.securityKeyText);
		securityKeyEditText.setText(Storage.getSecurityKey(this));
		String versionName = "v";
		try {
			versionName += getPackageManager().getPackageInfo(getPackageName(), 0).versionName;
		} catch (NameNotFoundException e) {
            Log.e("[SampleApp]","Exception while getting version name!!",e);
		}

		if(!AndroidDeviceInfo.isNetworkAvailable(this)){
			Toast.makeText(this, "Network Not Available!! Please Connect to Internet First.", Toast.LENGTH_LONG).show();
			finish();
		}

		((TextView) findViewById(R.id.tvVersion)).setText(versionName);

		findViewById(R.id.button_offerwall).setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				startActivity(new Intent(Pokkt.this, OfferwallActivity.class));
			}
		});

		findViewById(R.id.button_no_rewarded).setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {

				if (checkValidData()) {
					Intent intent = new Intent(Pokkt.this, VideoActivity.class);
					intent.putExtra("isIncent", false);
					intent.putExtra("screenName", editTextScreenName.getText().toString().trim());
					intent.putExtra("appId", appIdEditText.getText().toString().trim());
					intent.putExtra("securitykey", securityKeyEditText.getText().toString().trim());
					startActivity(intent);
				}
			}
		});

        findViewById(R.id.button_rewarded_ad).setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				if (checkValidData()) {
					Intent intent = new Intent(Pokkt.this, VideoActivity.class);
					intent.putExtra("isIncent", true);
					intent.putExtra("screenName", editTextScreenName.getText().toString().trim());
					intent.putExtra("appId", appIdEditText.getText().toString().trim());
					intent.putExtra("securitykey", securityKeyEditText.getText().toString().trim());
					startActivity(intent);
				}
			}
		});
	}

	boolean checkValidData() {

		if(TextUtils.isEmpty(appIdEditText.getText())) {
			Toast.makeText(Pokkt.this, "Please Enter App Id", Toast.LENGTH_LONG).show();
			return false;
		}

		if(TextUtils.isEmpty(securityKeyEditText.getText())) {
			Toast.makeText(Pokkt.this, "Please Enter security Key", Toast.LENGTH_LONG).show();
			return false;
		}

		if (TextUtils.isEmpty(editTextScreenName.getText())) {
			Toast.makeText(Pokkt.this, "Please Enter Screen Name or Zone ID", Toast.LENGTH_LONG).show();
			return false;
		}
		Storage.setAppId(this,appIdEditText.getText().toString());
		Storage.setSecurityKey(this,securityKeyEditText.getText().toString());
		return true;
	}

	@Override
	public void onConfigurationChanged(Configuration newConfig) {
		super.onConfigurationChanged(newConfig);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return super.onCreateOptionsMenu(menu);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
			case R.id.action_settings:
				toggleSettings();
				break;
			case R.id.action_export_log:
				PokktManager.exportLog(Pokkt.this);
				break;
		}
		return super.onOptionsItemSelected(item);
	}

	private void toggleSettings() {
		if(appIdEditText.isShown()) {
			appIdEditText.setVisibility(View.GONE);
			securityKeyEditText.setVisibility(View.GONE);
			appIdText.setVisibility(View.GONE);
			securityKeyText.setVisibility(View.GONE);
		} else {
			appIdEditText.setVisibility(View.VISIBLE);
			securityKeyEditText.setVisibility(View.VISIBLE);
			appIdText.setVisibility(View.VISIBLE);
			securityKeyText.setVisibility(View.VISIBLE);
		}
	}
}
