package com.bigflix.BigFlixMovies;

import android.app.Activity;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.app.pokktsdk.AdConfig;
import com.app.pokktsdk.PokktConfig;
import com.app.pokktsdk.PokktManager;
import com.app.pokktsdk.enums.IAPStoreType;
import com.app.pokktsdk.enums.PokktIntegrationType;
import com.app.pokktsdk.model.InAppPurchaseDetail;
import com.pokkt.videodemo.R;

public class VideoActivity extends Activity {
    public static boolean isPokktSDKReady = false;
    private Button btnPlayVideoWithIncent;
    private Button btnPlayVideoWithoutIncent;
    private Button btnStartVideoCaching;
    private boolean isIncent;
    private PokktConfig pokktConfig = new PokktConfig();
    private String screenName;
    private AdConfig adConfig;
    private TextView screenText;
    private String appId;
    private String securityKey;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        super.onCreate(savedInstanceState);

        setContentView(R.layout.video);

        btnStartVideoCaching = (Button) findViewById(R.id.button_start_cache);
        btnPlayVideoWithIncent = (Button) findViewById(R.id.button_video);
        btnPlayVideoWithoutIncent = (Button) findViewById(R.id.button_video_non_incent);

        screenText = (TextView)findViewById(R.id.textScreenName);
        btnStartVideoCaching.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                btnPlayVideoWithIncent.setVisibility(View.GONE);
                btnPlayVideoWithoutIncent.setVisibility(View.GONE);
                cacheAd();
            }
        });

        isIncent = getIntent().getBooleanExtra("isIncent", false);
        screenName = getIntent().getStringExtra("screenName");
        appId = getIntent().getStringExtra("appId");
        securityKey = getIntent().getStringExtra("securitykey");
        screenText.setText(screenName);
        adConfig = new AdConfig(screenName, isIncent);

        if (isIncent) {
            btnPlayVideoWithIncent.setVisibility(View.VISIBLE);
            btnPlayVideoWithoutIncent.setVisibility(View.GONE);
        } else {
            btnPlayVideoWithIncent.setVisibility(View.GONE);
            btnPlayVideoWithoutIncent.setVisibility(View.VISIBLE);
        }

        btnPlayVideoWithIncent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                PokktManager.checkAdAvailability(VideoActivity.this, adConfig);
            }
        });

        btnPlayVideoWithoutIncent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                PokktManager.checkAdAvailability(VideoActivity.this, adConfig);
            }
        });

        setUpPokkt();

        updateUI(Storage.getVideoPoints(this));
    }

    public void showAd(boolean isAdAvailable, AdConfig adConfig) {
        if(isAdAvailable) {
            AdConfig info = new AdConfig(screenName, isIncent);
            info.setShouldAllowSkip(true);
            info.setDefaultSkipTime(10);
            info.setBackButtonDisabled(true);
            if(isPokktSDKReady) {
                PokktManager.showAd(VideoActivity.this, info);
            } else {
                Toast.makeText(this, "Pokkt SDK Not Ready ", Toast.LENGTH_LONG).show();
            }
        }
    }

    @Override
    protected void onResume() {
        super.onResume();

    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
    }

    @Override
    public void onBackPressed() {
//		 If an interstitial is on screen, close it. Otherwise continue as normal.
            super.onBackPressed();
    }

    void cacheAd() {
        Log.d("VideoActivity", "Cache called");
        if(isPokktSDKReady) {
            PokktManager.cacheAd(VideoActivity.this, adConfig);
        } else {
            Toast.makeText(this, "Pokkt SDK Not Ready ", Toast.LENGTH_LONG).show();
        }
    }

    void updateUI(float points) {
        ((TextView) findViewById(R.id.points)).setText("Points earned: " + points);
        InAppPurchaseDetail details = new InAppPurchaseDetail();
        details.setProductId("xxx");
        details.setPrice((int) points);
        details.setCurrencyCode("INR");
        details.setDescription("COINS");
        details.setTitle("COIN");
        details.setPurchaseData(null);
        details.setPurchaseSignature(null);
        details.setPurchaseStore(IAPStoreType.NONE);
        PokktManager.trackIAP(VideoActivity.this, details);
    }

    void showButtons(float value, boolean isAdAvailable) {

        if(isAdAvailable) {
            if (isIncent) {
                btnPlayVideoWithIncent.setText("Show Incent Ad To Earn " + value + " (Caching)");
                btnPlayVideoWithIncent.setVisibility(View.VISIBLE);
                btnPlayVideoWithoutIncent.setVisibility(View.GONE);
            } else {
                btnPlayVideoWithoutIncent.setText("Show Non Incent Ad To Earn 0.0 (Caching)");
                btnPlayVideoWithIncent.setVisibility(View.GONE);
                btnPlayVideoWithoutIncent.setVisibility(View.VISIBLE);
            }
        } else {
            if (isIncent) {
                btnPlayVideoWithIncent.setVisibility(View.VISIBLE);
                btnPlayVideoWithoutIncent.setVisibility(View.GONE);
            } else {
                btnPlayVideoWithIncent.setVisibility(View.GONE);
                btnPlayVideoWithoutIncent.setVisibility(View.VISIBLE);
            }
        }
    }

    void resetButtonsText() {
        btnPlayVideoWithIncent.setText("Show Incent (Without Caching)");
        btnPlayVideoWithoutIncent.setText("Show Non-Incent (Without Caching)");
    }

    public void updatePoints(float points) {
        if (points == -1.00F) {
            // no points to be given.
        } else {
            updateUI(Storage.getVideoPoints(this));
        }
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
    }

    private void setUpPokkt() {
        // set the requisite parameters

        pokktConfig.setApplicationId(appId);
        pokktConfig.setSecurityKey(securityKey);
        pokktConfig.setIntegrationType(PokktIntegrationType.INTEGRATION_TYPE_ALL);
        // this will be a unique id per user from developer side
        // developer is free to choose any String data point.
        pokktConfig.setThirdPartyUserId("123456");

        PokktManager.setDebug(this, true);
        PokktManager.setAdDelegate(new AdDelegate(this));
        PokktManager.initPokkt(this, pokktConfig);
    }
}
